@@ -26,6 +26,7 @@
 #include "mlt_property.h"
 #include "mlt_deque.h"
 #include "mlt_log.h"
+#include "mlt_factory.h"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -35,7 +36,9 @@
 #include <pthread.h>
 #include <sys/types.h>
 #include <dirent.h>
-
+#include <sys/stat.h>
+#include <errno.h>
+#include <locale.h>
 
 /** \brief private implementation of the property list */
 
@@ -49,6 +52,7 @@ typedef struct
 	mlt_properties mirror;
 	int ref_count;
 	pthread_mutex_t mutex;
+	locale_t locale;
 }
 property_list;
 
@@ -116,12 +120,109 @@ mlt_properties mlt_properties_new( )
 	return self;
 }
 
+/** Set the numeric locale used for string/double conversions.
+ *
+ * \public \memberof mlt_properties_s
+ * \param self a properties list
+ * \param locale the locale name
+ * \return true if error
+ */
+
+int mlt_properties_set_lcnumeric( mlt_properties self, const char *locale )
+{
+	int error = 0;
+
+	if ( self && locale )
+	{
+		property_list *list = self->local;
+
+#if defined(__linux__) || defined(__DARWIN__)
+		if ( list->locale )
+			freelocale( list->locale );
+		list->locale = newlocale( LC_NUMERIC_MASK, locale, NULL );
+#endif
+		error = list->locale == NULL;
+	}
+	else
+		error = 1;
+
+	return error;
+}
+
+/** Get the numeric locale for this properties object.
+ *
+ * Do not free the result.
+ * \public \memberof mlt_properties_s
+ * \param self a properties list
+ * \return the locale name if this properties has a specific locale it is using, NULL otherwise
+ */
+
+const char* mlt_properties_get_lcnumeric( mlt_properties self )
+{
+	property_list *list = self->local;
+	const char *result = NULL;
+
+	if ( list->locale )
+	{
+#if defined(__DARWIN__)
+		result = querylocale( LC_NUMERIC, list->locale );
+#elif defined(__linux__)
+		result = list->locale->__names[ LC_NUMERIC ];
+#else
+		// TODO: not yet sure what to do on other platforms
+#endif
+	}
+	return result;
+}
+
+static int load_properties( mlt_properties self, const char *filename )
+{
+	// Open the file
+	FILE *file = fopen( filename, "r" );
+
+	// Load contents of file
+	if ( file != NULL )
+	{
+		// Temp string
+		char temp[ 1024 ];
+		char last[ 1024 ] = "";
+
+		// Read each string from the file
+		while( fgets( temp, 1024, file ) )
+		{
+			// Chomp the string
+			temp[ strlen( temp ) - 1 ] = '\0';
+
+			// Check if the line starts with a .
+			if ( temp[ 0 ] == '.' )
+			{
+				char temp2[ 1024 ];
+				sprintf( temp2, "%s%s", last, temp );
+				strcpy( temp, temp2 );
+			}
+			else if ( strchr( temp, '=' ) )
+			{
+				strcpy( last, temp );
+				*( strchr( last, '=' ) ) = '\0';
+			}
+
+			// Parse and set the property
+			if ( strcmp( temp, "" ) && temp[ 0 ] != '#' )
+				mlt_properties_parse( self, temp );
+		}
+
+		// Close the file
+		fclose( file );
+	}
+	return file? 0 : errno;
+}
+
 /** Create a properties object by reading a .properties text file.
  *
  * Free the properties object with mlt_properties_close().
  * \deprecated Please start using mlt_properties_parse_yaml().
  * \public \memberof mlt_properties_s
- * \param filename a string contain the absolute file name
+ * \param filename the absolute file name
  * \return a new properties object
  */
 
@@ -131,50 +232,83 @@ mlt_properties mlt_properties_load( const char *filename )
 	mlt_properties self = mlt_properties_new( );
 
 	if ( self != NULL )
-	{
-		// Open the file
-		FILE *file = fopen( filename, "r" );
-
-		// Load contents of file
-		if ( file != NULL )
-		{
-			// Temp string
-			char temp[ 1024 ];
-			char last[ 1024 ] = "";
-
-			// Read each string from the file
-			while( fgets( temp, 1024, file ) )
-			{
-				// Chomp the string
-				temp[ strlen( temp ) - 1 ] = '\0';
-
-				// Check if the line starts with a .
-				if ( temp[ 0 ] == '.' )
-				{
-					char temp2[ 1024 ];
-					sprintf( temp2, "%s%s", last, temp );
-					strcpy( temp, temp2 );
-				}
-				else if ( strchr( temp, '=' ) )
-				{
-					strcpy( last, temp );
-					*( strchr( last, '=' ) ) = '\0';
-				}
-
-				// Parse and set the property
-				if ( strcmp( temp, "" ) && temp[ 0 ] != '#' )
-					mlt_properties_parse( self, temp );
-			}
-
-			// Close the file
-			fclose( file );
-		}
-	}
+		load_properties( self, filename );
 
 	// Return the pointer
 	return self;
 }
 
+/** Set properties from a preset.
+ *
+ * Presets are typically installed to $prefix/share/mlt/presets/{type}/{service}/[{profile}/]{name}.
+ * For example, "/usr/share/mlt/presets/consumer/avformat/dv_ntsc_wide/DVD"
+ * could be an encoding preset for a widescreen NTSC DVD Video.
+ * Do not specify the type and service in the preset name parameter; these are
+ * inferred automatically from the service to which you are applying the preset.
+ * Using the example above and assuming you are calling this function on the
+ * avformat consumer, the name passed to the function should simply be DVD.
+ * Note that the profile portion of the path is optional, but a profile-specific
+ * preset with the same name as a more generic one is given a higher priority.
+ * \todo Look in a user-specific location - somewhere in the home directory.
+ *
+ * \public \memberof mlt_properties_s
+ * \param self a properties list
+ * \param name the name of a preset in a well-known location or the explicit path
+ * \return true if error
+ */
+
+int mlt_properties_preset( mlt_properties self, const char *name )
+{
+	struct stat stat_buff;
+
+	// validate input
+	if ( !( self && name && strlen( name ) ) )
+		return 1;
+
+	// See if name is an explicit file
+	if ( ! stat( name, &stat_buff ) )
+	{
+		return load_properties( self, name );
+	}
+	else
+	{
+		// Look for profile-specific preset before a generic one.
+		char *data          = getenv( "MLT_PRESETS_PATH" );
+		const char *type    = mlt_properties_get( self, "mlt_type" );
+		const char *service = mlt_properties_get( self, "mlt_service" );
+		const char *profile = mlt_environment( "MLT_PROFILE" );
+		int error = 0;
+
+		if ( data )
+		{
+			data = strdup( data );
+		}
+		else
+		{
+			data = malloc( strlen( mlt_environment( "MLT_DATA" ) ) + 9 );
+			strcpy( data, mlt_environment( "MLT_DATA" ) );
+			strcat( data, "/presets" );
+		}
+		if ( data && type && service )
+		{
+			char *path = malloc( 5 + strlen(name) + strlen(data) + strlen(type) + strlen(service) + ( profile? strlen(profile) : 0 ) );
+			sprintf( path, "%s/%s/%s/%s/%s", data, type, service, profile, name );
+			if ( load_properties( self, path ) )
+			{
+				sprintf( path, "%s/%s/%s/%s", data, type, service, name );
+				error = load_properties( self, path );
+			}
+			free( path );
+		}
+		else
+		{
+			error = 1;
+		}
+		free( data );
+		return error;
+	}
+}
+
 /** Generate a hash key.
  *
  * \private \memberof mlt_properties_s
@@ -491,6 +625,11 @@ int mlt_properties_pass_list( mlt_properties self, mlt_properties that, const ch
 
 
 /** Set a property to a string.
+ *
+ * The property name "properties" is reserved to load the preset in \p value.
+ * When the value begins with '@' then it is interpreted as a very simple math
+ * expression containing only the +, -, *, and / operators.
+ * The event "property-changed" is fired after the property has been set.
  *
  * This makes a copy of the string value you supply.
  * \public \memberof mlt_properties_s
@@ -521,6 +660,8 @@ int mlt_properties_set( mlt_properties self, const char *name, const char *value
 	{
 		error = mlt_property_set_string( property, value );
 		mlt_properties_do_mirror( self, name );
+		if ( !strcmp( name, "properties" ) )
+			mlt_properties_preset( self, value );
 	}
 	else if ( value[ 0 ] == '@' )
 	{
@@ -605,7 +746,8 @@ int mlt_properties_set_or_default( mlt_properties self, const char *name, const
 char *mlt_properties_get( mlt_properties self, const char *name )
 {
 	mlt_property value = mlt_properties_find( self, name );
-	return value == NULL ? NULL : mlt_property_get_string( value );
+	property_list *list = self->local;
+	return value == NULL ? NULL : mlt_property_get_string_l( value, list->locale );
 }
 
 /** Get a property name by index.
@@ -638,7 +780,7 @@ char *mlt_properties_get_value( mlt_properties self, int index )
 {
 	property_list *list = self->local;
 	if ( index >= 0 && index < list->count )
-		return mlt_property_get_string( list->value[ index ] );
+		return mlt_property_get_string_l( list->value[ index ], list->locale );
 	return NULL;
 }
 
@@ -812,7 +954,8 @@ int mlt_properties_set_int64( mlt_properties self, const char *name, int64_t val
 double mlt_properties_get_double( mlt_properties self, const char *name )
 {
 	mlt_property value = mlt_properties_find( self, name );
-	return value == NULL ? 0 : mlt_property_get_double( value );
+	property_list *list = self->local;
+	return value == NULL ? 0 : mlt_property_get_double_l( value, list->locale );
 }
 
 /** Set a property to a floating point value.
@@ -1085,7 +1228,7 @@ static int mlt_fnmatch( const char *wild, const char *file )
 
 static int mlt_compare( const void *self, const void *that )
 {
-	return strcmp( mlt_property_get_string( *( const mlt_property * )self ), mlt_property_get_string( *( const mlt_property * )that ) );
+    return strcmp( mlt_property_get_string( *( const mlt_property * )self ), mlt_property_get_string( *( const mlt_property * )that ) );
 }
 
 /** Get the contents of a directory.
@@ -1175,6 +1318,12 @@ void mlt_properties_close( mlt_properties self )
 				free( list->name[ index ] );
 			}
 
+#if defined(__linux__) || defined(__DARWIN__)
+			// Cleanup locale
+			if ( list->locale )
+				freelocale( list->locale );
+#endif
+
 			// Clear up the list
 			pthread_mutex_destroy( &list->mutex );
 			free( list->name );
@@ -1326,6 +1475,7 @@ static int parse_yaml( yaml_parser context, const char *namevalue )
 		if ( strcmp( ptr, "" ) == 0 )
 		{
 			mlt_properties child = mlt_properties_new();
+			mlt_properties_set_lcnumeric( child, mlt_properties_get_lcnumeric( properties ) );
 			mlt_properties_set_data( properties, name, child, 0,
 				( mlt_destructor )mlt_properties_close, NULL );
 			mlt_deque_push_front( context->stack, child );
@@ -1340,6 +1490,7 @@ static int parse_yaml( yaml_parser context, const char *namevalue )
 			mlt_properties child = mlt_properties_new();
 			char key[20];
 
+			mlt_properties_set_lcnumeric( child, mlt_properties_get_lcnumeric( properties ) );
 			snprintf( key, sizeof(key), "%d", context->index++ );
 			mlt_properties_set_data( properties, key, child, 0,
 				( mlt_destructor )mlt_properties_close, NULL );
@@ -1478,6 +1629,9 @@ static int parse_yaml( yaml_parser context, const char *namevalue )
 
 	error = mlt_properties_set( properties, name, value );
 
+	if ( !strcmp( name, "LC_NUMERIC" ) )
+		mlt_properties_set_lcnumeric( properties, value );
+
 	free( name_ );
 	free( value );
 
@@ -1508,6 +1662,9 @@ mlt_properties mlt_properties_parse_yaml( const char *filename )
 			char temp[ 1024 ];
 			char *ptemp = &temp[ 0 ];
 
+			// Default to LC_NUMERIC = C
+			mlt_properties_set_lcnumeric( self, "C" );
+
 			// Parser context
 			yaml_parser context = calloc( 1, sizeof( struct yaml_parser_context ) );
 			context->stack = mlt_deque_init();
@@ -1758,9 +1915,12 @@ static void serialise_yaml( mlt_properties self, strbuf output, int indent, int
 
 char *mlt_properties_serialise_yaml( mlt_properties self )
 {
+	const char *lc_numeric = mlt_properties_get_lcnumeric( self );
 	strbuf b = strbuf_new();
 	strbuf_printf( b, "---\n" );
+	mlt_properties_set_lcnumeric( self, "C" );
 	serialise_yaml( self, b, 0, 0 );
+	mlt_properties_set_lcnumeric( self, lc_numeric );
 	strbuf_printf( b, "...\n" );
 	char *ret = b->string;
 	strbuf_close( b );
