@@ -20,8 +20,10 @@
 
 #include <framework/mlt.h>
 #include <string.h>
+#include <limits.h>
 
 extern mlt_consumer consumer_null_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
+extern mlt_filter filter_audiochannels_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
 extern mlt_filter filter_audioconvert_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
 extern mlt_filter filter_audiowave_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
 extern mlt_filter filter_brightness_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
@@ -53,9 +55,38 @@ extern mlt_transition transition_luma_init( mlt_profile profile, mlt_service_typ
 extern mlt_transition transition_mix_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
 #include "transition_region.h"
 
+static mlt_properties metadata( mlt_service_type type, const char *id, void *data )
+{
+	char file[ PATH_MAX ];
+	const char *service_type = NULL;
+	switch ( type )
+	{
+		case filter_type:
+			service_type = "filter";
+			break;
+		case producer_type:
+			service_type = "producer";
+			break;
+		case transition_type:
+			service_type = "transition";
+			break;
+		default:
+			return NULL;
+	}
+	if ( !strcmp( id, "grayscale" ) )
+		id = "greyscale";
+	else if ( !strcmp( id, "color" ) )
+		id = "colour";
+	else if ( !strcmp( id, "channelswap" ) )
+		id = "channelcopy";
+	snprintf( file, PATH_MAX, "%s/core/%s_%s.yml", mlt_environment( "MLT_DATA" ), service_type, id );
+	return mlt_properties_parse_yaml( file );
+}
+
 MLT_REPOSITORY
 {
 	MLT_REGISTER( consumer_type, "null", consumer_null_init );
+	MLT_REGISTER( filter_type, "audiochannels", filter_audiochannels_init );
 	MLT_REGISTER( filter_type, "audioconvert", filter_audioconvert_init );
 	MLT_REGISTER( filter_type, "audiowave", filter_audiowave_init );
 	MLT_REGISTER( filter_type, "brightness", filter_brightness_init );
@@ -90,4 +121,30 @@ MLT_REPOSITORY
 	MLT_REGISTER( transition_type, "luma", transition_luma_init );
 	MLT_REGISTER( transition_type, "mix", transition_mix_init );
 	MLT_REGISTER( transition_type, "region", transition_region_init );
+
+	MLT_REGISTER_METADATA( filter_type, "audiowave", metadata, NULL );
+	MLT_REGISTER_METADATA( filter_type, "brightness", metadata, NULL );
+	MLT_REGISTER_METADATA( filter_type, "channelcopy", metadata, NULL );
+	MLT_REGISTER_METADATA( filter_type, "channelswap", metadata, NULL );
+	MLT_REGISTER_METADATA( filter_type, "crop", metadata, NULL );
+	MLT_REGISTER_METADATA( filter_type, "data_show", metadata, NULL );
+	MLT_REGISTER_METADATA( filter_type, "gamma", metadata, NULL );
+	MLT_REGISTER_METADATA( filter_type, "greyscale", metadata, NULL );
+	MLT_REGISTER_METADATA( filter_type, "grayscale", metadata, NULL );
+	MLT_REGISTER_METADATA( filter_type, "luma", metadata, NULL );
+	MLT_REGISTER_METADATA( filter_type, "mirror", metadata, NULL );
+	MLT_REGISTER_METADATA( filter_type, "mono", metadata, NULL );
+	MLT_REGISTER_METADATA( filter_type, "obscure", metadata, NULL );
+	MLT_REGISTER_METADATA( filter_type, "region", metadata, NULL );
+	MLT_REGISTER_METADATA( filter_type, "transition", metadata, NULL );
+	MLT_REGISTER_METADATA( filter_type, "watermark", metadata, NULL );
+	MLT_REGISTER_METADATA( producer_type, "colour", metadata, NULL );
+	MLT_REGISTER_METADATA( producer_type, "color", metadata, NULL );
+	MLT_REGISTER_METADATA( producer_type, "consumer", metadata, NULL );
+	MLT_REGISTER_METADATA( producer_type, "hold", metadata, NULL );
+	MLT_REGISTER_METADATA( producer_type, "noise", metadata, NULL );
+	MLT_REGISTER_METADATA( transition_type, "composite", metadata, NULL );
+	MLT_REGISTER_METADATA( transition_type, "luma", metadata, NULL );
+	MLT_REGISTER_METADATA( transition_type, "mix", metadata, NULL );
+	MLT_REGISTER_METADATA( transition_type, "region", metadata, NULL );
 }
