@@ -33,10 +33,11 @@
 static int filter_get_image( mlt_frame this, uint8_t **image, mlt_image_format *format, int *width, int *height, int writable )
 {
 	// Get the image
+	*format = mlt_image_yuv422;
 	int error = mlt_frame_get_image( this, image, format, width, height, 1 );
 
 	// Only process if we have no error and a valid colour space
-	if ( error == 0 && *format == mlt_image_yuv422 )
+	if ( error == 0 )
 	{
 		// Get the brightness level
 		double level = mlt_properties_get_double( MLT_FRAME_PROPERTIES( this ), "brightness" );
@@ -73,12 +74,8 @@ static mlt_frame filter_process( mlt_filter this, mlt_frame frame )
 	if ( mlt_properties_get( MLT_FILTER_PROPERTIES( this ), "end" ) != NULL )
 	{
 		// Determine the time position of this frame in the transition duration
-		mlt_position in = mlt_filter_get_in( this );
-		mlt_position out = mlt_filter_get_out( this );
-		mlt_position time = mlt_frame_get_position( frame );
-		double position = ( double )( time - in ) / ( double )( out - in + 1 );
 		double end = fabs( mlt_properties_get_double( MLT_FILTER_PROPERTIES( this ), "end" ) );
-		level += ( end - level ) * position;
+		level += ( end - level ) * mlt_filter_get_progress( this, frame );
 	}
 
 	// Push the frame filter
