@@ -118,8 +118,10 @@ static int producer_get_image( mlt_frame frame, uint8_t **buffer, mlt_image_form
 	// Parse the colour
 	if ( now && strchr( now, '/' ) )
 	{
-		now = strrchr( now, '/' ) + 1;
+		now = strdup( strrchr( now, '/' ) + 1 );
 		mlt_properties_set( producer_props, "resource", now );
+		free( now );
+		now = mlt_properties_get( producer_props, "resource" );
 	}
 	rgba_color color = parse_color( now, mlt_properties_get_int( producer_props, "resource" ) );
 
