@@ -43,18 +43,15 @@ static int producer_get_image( mlt_frame frame, uint8_t **buffer, mlt_image_form
 	*buffer = mlt_pool_alloc( size );
 
 	// Update the frame
-	mlt_properties_set_data( properties, "image", *buffer, size, mlt_pool_release, NULL );
-	mlt_properties_set_int( properties, "width", *width );
-	mlt_properties_set_int( properties, "height", *height );
+	mlt_frame_set_image( frame, *buffer, size, mlt_pool_release );
 
 	*format = mlt_image_rgb24a;
 	if ( *buffer != NULL )
 	{
-		mlt_position in = mlt_producer_get_in( producer );
-		mlt_position out = mlt_producer_get_out( producer );
-		mlt_position time = mlt_frame_get_position( frame );
-		double position = ( double )( time - in ) / ( double )( out - in + 1 );
-		process_frei0r_item( producer_type, position, producer_props, frame, buffer, width, height );
+		double position = mlt_frame_get_position( frame );
+		mlt_profile profile = mlt_service_profile( MLT_PRODUCER_SERVICE( producer ) );
+		double time = position / mlt_profile_fps( profile );
+		process_frei0r_item( MLT_PRODUCER_SERVICE(producer), position, time, producer_props, frame, buffer, width, height );
 	}
 
     return 0;
